##############################################
## Figure 3: CARs for April 17, 2013 vs. Companies’ Exposure to ATS Claims
##############################################

rm(list = ls())
setwd(wk_dir)

# Loading data:
load("Data/April17.Rdata")

# Loading Plot Options:
source("Code/Helper_Scripts/Plot_Options.R")

##############################################

f1 <- ggplot(data = filter(rep_17apr, !is.na(min_physint)),
    aes(x = factor(min_physint), y = car)) +
    stat_summary(fun.data = "mean_cl_boot", geom = "pointrange") +
    geom_jitter(position = position_jitter(width = .1),
        alpha = .4, size = 1.5) +
    geom_smooth(aes(x = min_physint + 1, y = car),
        method = "lm", lty = 2, se = TRUE, alpha = .2, color = "black") +
    #coord_cartesian(ylim = c(-.5, .5)) +
    scale_color_brewer(palette = "Set1", guide = FALSE) +
    scale_x_discrete("Rights Index",
        breaks = c(0, 2, 4, 6, 8),
        labels = c("Worst", "2", "4", "6", "Best")) +
    ylab("Cumulative Abnormal Returns") +
    theme_bw() + dc_opts

f2 <- ggplot(data = filter(rep_17apr, !is.na(min_physint)),
    aes(x = factor(min_physint), y = car, color = foreign)) +
    stat_summary(fun.data = "mean_cl_boot", geom = "pointrange") +
    geom_jitter(position = position_jitter(width = .1),
        alpha = .4, size = 1.5) +
    geom_smooth(aes(x = min_physint + 1, y = car),
        method = "lm", lty = 2, se = TRUE, alpha = .2) +
    facet_wrap(~foreign) +
    #coord_cartesian(ylim = c(-.5, .5)) +
    scale_color_brewer(palette = "Set1", guide = FALSE) +
    scale_x_discrete("Rights Index",
        breaks = c(0, 2, 4, 6, 8),
        labels = c("Worst", "2", "4", "6", "Best")) +
    ylab("Cumulative Abnormal Returns") +
    theme_bw() + dc_opts +
    theme(strip.text = element_text(size = 16),
        strip.background = element_rect(color = "transparent", fill = "transparent"))

grid.arrange(f1, f2, nrow = 1)
