##############################################
## Table 4: Regression Results for Ruling (April 17, 2013)
##############################################

rm(list = ls())
setwd(wk_dir)

# Loading data:
load("Data/April17.Rdata")

# Loading Plot Options:
source("Code/Helper_Scripts/Plot_Options.R")

##############################################
# Reference level for factor:
rep_17apr$foreign <- with(rep_17apr, relevel(factor(foreign), ref = "US"))

# Model 1:
m1 <- lm(car ~ min_physint, data = rep_17apr)
se1 <- sqrt(diag(vcovHC(m1)))

# Model 2:
m2 <- lm(car ~ min_physint + foreign + min_physint:foreign,
    data = rep_17apr)
se2 <- sqrt(diag(vcovHC(m2)))

# Model 3:
m3 <- lm(car ~ min_physint + foreign + min_physint:foreign + nace_cat, data = rep_17apr,
    subset = nace_cat %nin% c("Uranium", "Support Mining", "Fertilizer", "Building Stone", "Gravel and Sand", "Salt"))
se3 <- sqrt(diag(vcovHC(m3)))

##############################################
# Outputting LaTeX table:

stargazer(m1, m2, m3,
    se = list(se1, se2, se3[!grepl("nace", names(se3))]),
    omit = "nace",
    dep.var.labels = "CAR",
    covariate.labels = c("Rights Index", "$\\mathbb{1}$(Foreign)", "Rights Index$\\times \\mathbb{1}$(Foreign)"),
    ci = FALSE,
    omit.stat = c("rsq", "ser", "f"),
    font.size = "footnotesize",
    label = "tab:dv_car",
    title = "Regression Results for Ruling (April 17, 2013)",
    add.lines = list(c("Sub-Sector FE", "", "", "\\checkmark")),
    notes = "Robust Std. Errors in parentheses.",
    notes.append = TRUE)
