##############################################
## "Measuring the Economic Effect of Alien Tort Statute Liability"
## Date: January 6, 2016
## Authors: Darin Christensen and David Hausmann
##############################################

# Clearing workspace
rm(list = ls())
.wk_env <- new.env()

# ** INCLUDE YOUR PATH HERE: **
.wk_env$wk_dir <- "~/Dropbox/Alien_Tort_Statute/Replication"
.wk_env$"%nin%" <- function(x, y) !(x %in% y)
attach(.wk_env, warn.conflicts = FALSE)

setwd(wk_dir)

# Option to print 3 significant digits:
options(digits = 3)

# Loading Packages:
pkgs <- c("stringr", "stringdist", "reshape", "lubridate", "RColorBrewer", "foreign", "ggplot2", "dplyr", "beepr", "data.table", "lmtest", "sandwich", "reporttools", "stargazer", "scales", "grid", "gridExtra", "extrafont", "Hmisc")

pkg_load <- sapply(pkgs, require, character.only = TRUE, quietly = TRUE)

# Installing any missing packages:
if(all(pkg_load)) {
    message("All required packages installed.")
} else {
    suppressWarnings(install.packages(pkgs[which(!pkg_load)]))
    pkg_load <- suppressWarnings(sapply(pkgs[which(!pkg_load)], require, character.only = TRUE))

    if(any(!pkg_load)){message("*** STOP. A required package has not been installed or loaded. ***")}
}
rm(list = c("pkgs", "pkg_load"))

##############################################
## Figure 1: Corporate ATS Cases from 1960-2010
##############################################

setwd(wk_dir)
source("Code/Fig1.R")

##############################################
## Table 2: Summary Statistics
##############################################

# Note: This table was compiled manually from the following output.
setwd(wk_dir)
source("Code/Table2.R")

##############################################
## Figure 2: Selected Firms’ Stock Prices during April 17, 2013 Event Window
##############################################

setwd(wk_dir)
source("Code/Fig2.R")

##############################################
## Figure 3: CARs for April 17, 2013 vs. Companies’ Exposure to ATS Claims
##############################################

setwd(wk_dir)
source("Code/Fig3.R")

##############################################
## Table 3: Regression Results for Rehearing (March 5, 2012)
##############################################

setwd(wk_dir)
source("Code/Table3.R")

##############################################
## Table 4: Regression Results for Ruling (April 17, 2013)
##############################################

setwd(wk_dir)
source("Code/Table4.R")

##############################################
## Figure 4: Stock Price Series for Other ATS Defendants
##############################################

setwd(wk_dir)
source("Code/Fig4.R")

##############################################
## Figure 5: Estimates Using Event Windows of Varying Length
##############################################

setwd(wk_dir)
source("Code/Fig5.R")

##############################################
## Table 5: Rehearing (3/5/2012)
##############################################

setwd(wk_dir)
source("Code/Table5.R")

##############################################
## Table 6: Ruling (4/17/2013)
##############################################

setwd(wk_dir)
source("Code/Table6.R")

##############################################
## Figure 6: Distribution of Placebo Tests
##############################################

# Warning: This script is very time-consuming. Uncomment to run.
# source("Code/Fig6.R")

##############################################
## SessionInfo
##############################################

sessionInfo()
# R version 3.2.2 (2015-08-14)
# Platform: x86_64-apple-darwin13.4.0 (64-bit)
# Running under: OS X 10.11.2 (El Capitan)

# locale:
# [1] C

# attached base packages:
# [1] grid      graphics  grDevices utils     datasets  stats     methods
# [8] base

# other attached packages:
#  [1] stargazer_5.2      Hmisc_3.17-0       Formula_1.2-1      survival_2.38-3
#  [5] lattice_0.20-33    extrafont_0.17     gridExtra_2.0.0    scales_0.3.0
#  [9] reporttools_1.1.2  xtable_1.7-4       sandwich_2.3-4     lmtest_0.9-34
# [13] zoo_1.7-12         RColorBrewer_1.1-2 stringdist_0.9.3   stringr_1.0.0
# [17] data.table_1.9.6   beepr_1.2          dplyr_0.4.3        ggplot2_1.0.1
# [21] foreign_0.8-66     lubridate_1.3.3

# loaded via a namespace (and not attached):
#  [1] Rcpp_0.12.1         plyr_1.8.3          tools_3.2.2
#  [4] rpart_4.1-10        digest_0.6.8        memoise_0.2.1
#  [7] gtable_0.1.2        DBI_0.3.1           parallel_3.2.2
# [10] proto_0.3-10        Rttf2pt1_1.3.3      cluster_2.0.3
# [13] nnet_7.3-11         reshape_0.8.5       R6_2.1.1
# [16] latticeExtra_0.6-26 reshape2_1.4.1      extrafontdb_1.0
# [19] magrittr_1.5        splines_3.2.2       MASS_7.3-44
# [22] assertthat_0.1      colorspace_1.2-6    labeling_0.3
# [25] stringi_0.5-5       acepack_1.3-3.3     lazyeval_0.1.10
# [28] munsell_0.4.2       chron_2.3-47        audio_0.1-5
